1.2.0 2015-03-19
----------------

- Remove playlists provider.

- Add bookmarks to root directory for browsing.


1.1.0 2014-11-19
----------------

- Load bookmarks as individual playlists.

- Clear library cache when refreshing playlists.

- Encode filenames in URIs.

- Add HTTP connection retries.


1.0.3 2014-11-14
----------------

- Fix handling of re-derived VBR MP3 files.

- Remove Ogg Vorbis from default audio formats.


1.0.2 2014-11-07
----------------

- Update dependencies.

- Browse Internet Archive items as albums.

- Make caching optional.

- Disable PNG image format in default configuration.

- Temporarily disable VBR MP3 and track comments.


1.0.1 2014-09-29
----------------

- Add item descriptions as track comments.

- Filter search results for exact queries.


1.0.0 2014-09-26
----------------

- Major rewrite for version 1.0.0.


0.5.0 2014-02-28
----------------

- Update `README` with link to documentation.

- New config values: ``search_order``, ``browse_order``.

- Allow empty queries for searching.


0.4.0 2014-02-25
----------------

- Various performance and stability improvements.

- Option to exclude specific collections from searching/browsing.

- Add image URLs to albums.


0.3.1 2014-02-21
----------------

- Fix default configuration.


0.3.0 2014-02-21
----------------

- Add bookmark browsing support.

- Better filtering of search results.

- Stability and performance improvements.


0.2.0 2014-01-31
----------------

- Add library browsing support.

- Cache search results and metadata.

- Properly quote/encode query terms.


0.1.0 2014-01-24
----------------

- Initial release.
